==> haskell-fgl-arbitrary-0.2.0.6-209-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fgl-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fgl-arbitrary
version:              0.2.0.6
visibility:           public
id:                   fgl-arbitrary-0.2.0.6-14OkoifK7ni9PfYhpS3c3w
key:                  fgl-arbitrary-0.2.0.6-14OkoifK7ni9PfYhpS3c3w
license:              BSD-3-Clause
copyright:            Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             QuickCheck support for fgl
description:
    Provides Arbitrary instances for fgl graphs (to avoid adding a
    QuickCheck dependency for fgl whilst still making the instances
    available to others).

    Also available are non-fgl-specific functions for generating
    graph-like data structures.

category:             Testing, Graphs
abi:                  7ff7c6ae73b1f36845284a312dc5ef24
exposed:              True
exposed-modules:      Data.Graph.Inductive.Arbitrary
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fgl-arbitrary-0.2.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fgl-arbitrary-0.2.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fgl-arbitrary-0.2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fgl-arbitrary
hs-libraries:         HSfgl-arbitrary-0.2.0.6-14OkoifK7ni9PfYhpS3c3w
depends:
    QuickCheck-2.15.0.1-KEw9aoMxM6q6i8cfYYug2V base-4.17.2.1
    fgl-5.8.3.0-HB304WeKiosDGhHcaUgJEX

haddock-interfaces:
    /usr/share/doc/haskell-fgl-arbitrary/html/fgl-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-fgl-arbitrary/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fgl-arbitrary-0.2.0.6-210-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fgl-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fgl-arbitrary
version:              0.2.0.6
visibility:           public
id:                   fgl-arbitrary-0.2.0.6-AjmBTXGqOxqLpoCZ3E8lFC
key:                  fgl-arbitrary-0.2.0.6-AjmBTXGqOxqLpoCZ3E8lFC
license:              BSD-3-Clause
copyright:            Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             QuickCheck support for fgl
description:
    Provides Arbitrary instances for fgl graphs (to avoid adding a
    QuickCheck dependency for fgl whilst still making the instances
    available to others).

    Also available are non-fgl-specific functions for generating
    graph-like data structures.

category:             Testing, Graphs
abi:                  d4f57c4d0a98b2c120ebe5aa309d8a4b
exposed:              True
exposed-modules:      Data.Graph.Inductive.Arbitrary
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fgl-arbitrary-0.2.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fgl-arbitrary-0.2.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fgl-arbitrary-0.2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fgl-arbitrary
hs-libraries:         HSfgl-arbitrary-0.2.0.6-AjmBTXGqOxqLpoCZ3E8lFC
depends:
    QuickCheck-2.15.0.1-7dsjbuPrJB87A5nQdB1dNE base-4.17.2.1
    fgl-5.8.3.0-50Gd1ceAR9W5tO6iSQxnuZ

haddock-interfaces:
    /usr/share/doc/haskell-fgl-arbitrary/html/fgl-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-fgl-arbitrary/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
